# ccal-noir
Clone of CCAL with calls to R removed. In fact, it is a copy and paste of the functions being used for the Omics Collections. Not all of CCAL functionalities are supported here, only match_to_profile.
